[![Tests](https://github.com/hubplug/modern-python-setup/workflows/Tests/badge.svg)](https://github.com/hubplug/modern-python-setup/actions?workflow=Tests)
[![Codecov](https://codecov.io/gh/hubplug/modern-python-setup/branch/master/graph/badge.svg)](https://codecov.io/gh/hubplug/modern-python-setup)
[![PyPI](https://img.shields.io/pypi/v/modern-python-setup.svg)](https://pypi.org/project/modern-python-setup/)

# modern-python-setup
Based on [Hypermodern Python](https://cjolowicz.github.io/posts/hypermodern-python-01-setup/) by [CLAUDIO JOLOWICZ](https://cjolowicz.github.io/)
